---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is. Using Polylidar as Python or pure C++.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment  (please complete the following information):**
 - OS: [e.g. WIndows, Linux, MacOS]
 - Architecture (x64, Arm)
 - Version [e.g. 0.0.6]

**Additional context**
Add any other context about the problem here.
